Index: branches/FEPSimulator/FEPSim.h
===================================================================
--- branches/FEPSimulator/FEPSim.h	(revision 221)
+++ branches/FEPSimulator/FEPSim.h	(revision 233)
@@ -4,18 +4,11 @@
  * The FEP Simulator simulates the Front End Processor(FEP), which has the
  * responsibility of "polling" Loop Detector Stations for highway status data.
- * The real FEP "polls" real stations over serial communication lines, whereas
- * the FEP Simulator recieves highway status data through a socket from the Java
- * ATMS Driver.
+ * The actual FEP "polls" actual stations over serial communication lines, whereas
+ * the FEP Simulator receives highways status data over a socket from the Java
+ * ATMS Driver. The highways status data is then parsed by the Network Reader.
  * 
- * Highway status data is transmitted to the FEP Simulator over the socket in
- * XML Form. The XML highway status data is then parsed by the Network Reader.
- * 
- * The data is then sent to the ATMS, using RPC Calls. The RPC Calls to the
- * ATMS Server send an fep_reply structure. There is one fep_reply structure
- * sent to the ATMS for every FEP_LINE.
- *
- * The FEP Simulator is a socket server that runs persistently and awaits the
- * XML highway status data over the socket. When the XML highway status data is
- * recieved, it executes the RPC Calls to update the ATMS.
+ * The data is reconfigured into an fep_reply struct, then sent to the ATMS via 
+ * RPC Calls. The RPC Calls to the ATMS Server send an the fep_reply structs. 
+ * There is one fep_reply structure sent to the ATMS for every station.
  *
  * @author John A. Torres
@@ -43,6 +36,10 @@
 #include <netinet/in.h>
 #include <unistd.h>
+#include <time.h>
 
+// this buffer is the size of the entire highways data message + 1 for the
+// appended newline character, when sent over the socket
 const int BUFF_SIZE = 1266341;
+// Log file for FEPSimulator
 static ofstream FEPLogFile;
     
@@ -63,6 +60,6 @@
     
     /**
-     * Creates a socket server and awaits the highway status XML responses from the
-     * ATMS Driver. Upon reciept of the highway status XML message, creates an RPC
+     * Creates a socket server and awaits the highway status message from the
+     * ATMS Driver. Upon receipt of the highway status message, creates an RPC
      * client and sends the fep_replys to the ATMS.
      */
@@ -71,19 +68,23 @@
     /**
      * Creates an RPC Client, and on successful creation, sends fep_replys to ATMS.
-     * @param The recieved highway status xml.
+     * @param The recieved highway status msg.
      */
-    void manageClientConnection(char * xml);
+    void manageClientConnection(char * buffer);
     
     /**
-     * Destructor: Does nothing, no cleaning necessary
+     * Destructor: closes the log file if open
      */
     ~FEPSim(); // Destructor
 
 private:
-    /* members */
+    // atms ip address
     char * ATMSHost;
+    // rpc program number
     int FEP_PROG;
+    // rpc revision number
     int FEP_REV;
+    // socket port
     int SOCK_PORT;
+    // name of logging file
     char * FEPLogFileName;
     
@@ -95,15 +96,16 @@
     
     /**
-     * Creates the RPC Client. If not successful, returns false.
+     * Creates an RPC Client to the ATMS Server. If unsuccessful, returns false
+     * @return bool success
      */
     bool createClient();
     
     /**
      * Sends an fep_reply for each FEP_LINE. Gets highway status from recieved XML
      * data.
      * @param xml The recieved highway status XML.
      */
-    void sendReplys(char * xml);
-    
+    void sendReplys(char * buffer);
 };
 
@@ -95,15 +96,16 @@
     
     /**
-     * Sends an fep_reply for each FEP_LINE. Gets highway status from recieved XML
-     * data.
-     * @param xml The recieved highway status XML.
+     * Sends an fep_reply for each station on the FEPLine. 
+     * Gets highway status from recieved socket msg.
+     * 
+     * @param buffer The recieved highway status msg.
      */
